@@ -75,7 +75,7 @@ class Connection:
         productRegisterID: str = "",
     ):
         result = register_consumer(
-            register_url=self.endpoints.consumer_register,
+            custom_api=self.endpoints,
             email=email,
             phone=phone,
             password=password,
