@@ -1,5 +1,5 @@
-from .types import APIs
+from .types import API
 
 DOMAIN = "https://staging.orijinplusserver.com"
-ENDPOINTS = APIs(DOMAIN)
+ENDPOINTS = API(DOMAIN)
 ENDPOINTS.domain = DOMAIN
\ No newline at end of file
