@@ -1,17 +1,18 @@
 from datetime import datetime
 
 
-class APIs:
+class API:
     """For IDE prompting (instead of entering API addresses all over the place), define what endpoints the system will use endpoints here."""
     def __init__(
         self,
-        domain: str            = "",
+        domain: str            = "http://staging.orijinplusserver.com/",
         gql: str               = "/api/gql/query",
         file_uploads: str      = "/api/gql/query",
         consumer_login: str    = "/api/auth/customer/login",
         consumer_register: str = "/api/auth/customer/register",
         brand_login: str       = "/api/auth/login",
         brand_register: str    = "/api/auth/member/register",
+        firebase_apikey: str   = "AIzaSyCfKfU1bKdiAM7PALLzQ1M3R4Lt5s3Ns78",
     ) -> None:
         self.gql                = domain.strip('/') + gql
         self.file_uploads       = domain.strip('/') + file_uploads
@@ -19,6 +20,8 @@ class APIs:
         self.consumer_register  = domain.strip('/') + consumer_register
         self.brand_login        = domain.strip('/') + brand_login
         self.brand_register     = domain.strip('/') + brand_register
+        self.firebase_register  = f"https://identitytoolkit.googleapis.com/v1/accounts:signUp?key={firebase_apikey}"
+        self.firebase_login     = f"https://identitytoolkit.googleapis.com/v1/accounts:signInWithPassword?key={firebase_apikey}"
 
 class Profile:
     def __init__(
